<template>
    <div class="player-container">
        <div id="wsplayer"></div>
    </div>
</template>
<script>
export default {
    name: 'DHPlayer',
    data() {
        return {
            WSPlayer: null,
        }
    },
    created() {
        this.initPlayer()
    },
    methods: {
        initPlayer() {
            this.WSPlayer = new window.PlayerManager({
                el: 'wsplayer' /** 实时预览容器id，创建多个播放器，传入不同的容器id即可 **/,
                type: 'real' /** real - 实时预览  record - 录像回放 **/,
                STATIC_PATH: '/wsplayer-gov',
                maxNum: 16,
                num: 4,
                showControl: true,
                showRecordProgressBar: true,
                useNginxProxy: false,
                nginxProxyHost: '',
                showIcons: {
                    streamChangeSelect: true,
                    localRecordIcon: true,
                    audioIcon: true,
                    snapshotIcon: true,
                    closeIcon: true,
                    extendIcons: [
                        {
                            className: 'extend-icon',
                            title: '自定义',
                            onClick: (index, channelCode, channelData) => {
                                alert(
                                    `点击第${index}个窗口，channelCode为${channelCode},channelName为${channelData.channelName}`
                                )
                            },
                        },
                    ],
                },
                downloadMp4Record: true,
                localRecordSize: 100,
                playerAdapter: 'stretching',
                picCapName: (index, channelCode, channelData) => {
                    return `抓图_第${
                        index + 1
                    }个窗口_channelCode-${channelCode}_channelName-${
                        channelData.channelName
                    }_${Date.now()}`
                },
                localRecordName: (index, channelCode, channelData) => {
                    return `录像_第${
                        index + 1
                    }个窗口_channelCode-${channelCode}_channelName-${
                        channelData.channelName
                    }_${Date.now()}`
                },
                receiveMessageFromWSPlayer: (type) => {
                    if (type === 'initializationCompleted') {
                        this.WSPlayer.playRealVideo({
                            channelList: [
                                {
                                    channelCode: 'xxx',
                                    channelName: 'yyyyy',
                                },
                            ],
                            streamType: 2,
                            searchOnline: true,
                        })
                    }
                },
            })
        },
        play(camera) {
            let {channelCode} = camera
            this.WSPlayer.playRealVideo({
                // 通道列表信息
                channelList: [
                    {
                        channelCode: 'xxxx', // 通道code，也可使用id作为参数传递
                        isOnline: true, // 是否在线，false时不会去获取rtsp地址和拉流
                        cameraType: 2, // 相机类型 1-枪机；2-球机；3-半球机
                        // channelName: '', // 非必填，通道信息，随extendIcons的onClick、picCapName和localRecordName的回调一并返回
                    },
                ],
                streamType: 1, // 码流类型   1-主码流；2-辅码流1；3-辅码流2；默认为辅码流1
                // windowIndex: 0, //  窗口索引 默认为当前的已选窗口
                searchOnline: false, // 是否组件内部调用vsl接口获取通道的在线状态，会覆盖channelList的isOnline
            })
        },
        close() {
            this.WSPlayer.destroy()
        },
    },
    beforeDestroy() {
        this.close()
    },
}
</script>
<style lang="scss" scoped>
.player-container{
    width: 100%;
    height: 100%;
    display: flex;
    flex-wrap: wrap;
    align-content: flex-start;
    box-sizing: border-box;
    background-color: #333;
}
#wsplayer{
    width: 100%;
    height: 100%;
}
</style>